gapipy.resources package
========================

Subpackages
-----------

.. toctree::

    gapipy.resources.booking
    gapipy.resources.geo
    gapipy.resources.tour

Submodules
----------

gapipy.resources.base module
----------------------------

.. automodule:: gapipy.resources.base
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.language module
--------------------------------

.. automodule:: gapipy.resources.language
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: gapipy.resources
    :members:
    :undoc-members:
    :show-inheritance:
